@@ -548,12 +548,12 @@ public:
     /**
         Adds new button, with given label.
     */
-    void Add( const wxString& label, int id = -2 );
+    void Add( const wxString& label, int id = wxID_ANY );
 
     /**
         Adds new bitmap button.
     */
-    void Add( const wxBitmapBundle& bitmap, int id = -2 );
+    void Add( const wxBitmapBundle& bitmap, int id = wxID_ANY );
 
     /**
         Call this in CreateControls() of your custom editor class
