@@ -96,6 +96,18 @@ public:
      */
     static bool UseDefault();
 
+    /**
+        Return true if the locale was set by calling either UseDefault() or
+        UseLocaleName().
+
+        It is typically not necessary to call this function, as GetCurrent()
+        always returns a valid object, but it can be used to check whether an
+        application-set locale or the default one is being used.
+
+        @since 3.3.1
+     */
+    static bool IsSet();
+
     /**
         Get the object corresponding to the currently used locale.
 
