@@ -2,7 +2,6 @@
 // Name:        demo.cpp
 // Purpose:     wxHelpController demo
 // Author:      Karsten Ballueder
-// Modified by:
 // Created:     04/01/98
 // Copyright:   (c) Karsten Ballueder, Julian Smart
 // Licence:     wxWindows licence
@@ -92,10 +91,10 @@ public:
     // this one is called on application startup and is a good place for the app
     // initialization (doing it here and not in the ctor allows to have an error
     // return: if OnInit() returns false, the application terminates)
-    virtual bool OnInit() wxOVERRIDE;
+    virtual bool OnInit() override;
 
     // do some clean up here
-    virtual int OnExit() wxOVERRIDE;
+    virtual int OnExit() override;
 };
 
 // Define a new frame type: this is going to be our main frame
@@ -373,7 +372,7 @@ bool MyApp::OnInit()
 int MyApp::OnExit()
 {
     // clean up
-    delete wxHelpProvider::Set(NULL);
+    delete wxHelpProvider::Set(nullptr);
 
     return 0;
 }
@@ -384,7 +383,7 @@ int MyApp::OnExit()
 
 // frame constructor
 MyFrame::MyFrame(const wxString& title, const wxPoint& pos, const wxSize& size)
-       : wxFrame((wxFrame *)NULL, 300, title, pos, size)
+       : wxFrame(nullptr, 300, title, pos, size)
 #if USE_HTML_HELP
     , m_embeddedHtmlHelp(wxHF_EMBEDDED|wxHF_DEFAULT_STYLE)
 #endif
