@@ -90,15 +90,15 @@ enum
 class ComboboxWidgetsPage : public ItemContainerWidgetsPage
 {
 public:
-    ComboboxWidgetsPage(WidgetsBookCtrl *book, wxImageList *imaglist);
+    ComboboxWidgetsPage(WidgetsBookCtrl *book, wxVector<wxBitmapBundle>& imaglist);
 
-    virtual wxWindow *GetWidget() const wxOVERRIDE { return m_combobox; }
-    virtual wxTextEntryBase *GetTextEntry() const wxOVERRIDE { return m_combobox; }
-    virtual wxItemContainer* GetContainer() const wxOVERRIDE { return m_combobox; }
-    virtual void RecreateWidget() wxOVERRIDE { CreateCombo(); }
+    virtual wxWindow *GetWidget() const override { return m_combobox; }
+    virtual wxTextEntryBase *GetTextEntry() const override { return m_combobox; }
+    virtual wxItemContainer* GetContainer() const override { return m_combobox; }
+    virtual void RecreateWidget() override { CreateCombo(); }
 
     // lazy creation of the content
-    virtual void CreateContent() wxOVERRIDE;
+    virtual void CreateContent() override;
 
 protected:
     // event handlers
@@ -236,16 +236,16 @@ IMPLEMENT_WIDGETS_PAGE(ComboboxWidgetsPage, "Combobox",
                        );
 
 ComboboxWidgetsPage::ComboboxWidgetsPage(WidgetsBookCtrl *book,
-                                         wxImageList *imaglist)
+                                         wxVector<wxBitmapBundle>& imaglist)
                   : ItemContainerWidgetsPage(book, imaglist, combobox_xpm)
 {
     // init everything
     m_chkSort =
     m_chkReadonly =
-    m_chkProcessEnter = (wxCheckBox *)NULL;
+    m_chkProcessEnter = nullptr;
 
-    m_combobox = (wxComboBox *)NULL;
-    m_sizerCombo = (wxSizer *)NULL;
+    m_combobox = nullptr;
+    m_sizerCombo = nullptr;
 }
 
 void ComboboxWidgetsPage::CreateContent()
@@ -259,6 +259,15 @@ void ComboboxWidgetsPage::CreateContent()
     wxSizer *sizerTop = new wxBoxSizer(wxHORIZONTAL);
 
     // upper left pane
+    wxStaticBoxSizer *sizerLeftTop = new wxStaticBoxSizer(wxVERTICAL, this, "&Popup");
+    wxStaticBox* const sizerLeftTopBox = sizerLeftTop->GetStaticBox();
+
+    sizerLeftTop->Add(new wxButton(sizerLeftTopBox, ComboPage_Popup, "&Show"),
+                         wxSizerFlags().Border().Centre());
+    sizerLeftTop->Add(new wxButton(sizerLeftTopBox, ComboPage_Dismiss, "&Hide"),
+                         wxSizerFlags().Border().Centre());
+
+    // lower left pane
 
     // should be in sync with ComboKind_XXX values
     static const wxString kinds[] =
@@ -268,29 +277,23 @@ void ComboboxWidgetsPage::CreateContent()
         "drop down",
     };
 
-    m_radioKind = new wxRadioBox(this, wxID_ANY, "Combobox &kind:",
+    wxStaticBoxSizer *sizerLeftBottom = new wxStaticBoxSizer(wxVERTICAL, this, "&Set style");
+    wxStaticBox* const sizerLeftBottomBox = sizerLeftBottom->GetStaticBox();
+
+    m_radioKind = new wxRadioBox(sizerLeftBottomBox, wxID_ANY, "Combobox &kind:",
                                  wxDefaultPosition, wxDefaultSize,
                                  WXSIZEOF(kinds), kinds,
                                  1, wxRA_SPECIFY_COLS);
 
-    wxSizer *sizerLeftTop = new wxStaticBoxSizer(wxVERTICAL, this, "&Set style");
+    m_chkSort = CreateCheckBoxAndAddToSizer(sizerLeftBottom, "&Sort items", wxID_ANY, sizerLeftBottomBox);
+    m_chkReadonly = CreateCheckBoxAndAddToSizer(sizerLeftBottom, "&Read only", wxID_ANY, sizerLeftBottomBox);
+    m_chkProcessEnter = CreateCheckBoxAndAddToSizer(sizerLeftBottom, "Process &Enter", wxID_ANY, sizerLeftBottomBox);
 
-    m_chkSort = CreateCheckBoxAndAddToSizer(sizerLeftTop, "&Sort items");
-    m_chkReadonly = CreateCheckBoxAndAddToSizer(sizerLeftTop, "&Read only");
-    m_chkProcessEnter = CreateCheckBoxAndAddToSizer(sizerLeftTop, "Process &Enter");
+    sizerLeftBottom->Add(5, 5, 0, wxGROW | wxALL, 5); // spacer
+    sizerLeftBottom->Add(m_radioKind, 0, wxGROW | wxALL, 5);
 
-    sizerLeftTop->Add(5, 5, 0, wxGROW | wxALL, 5); // spacer
-    sizerLeftTop->Add(m_radioKind, 0, wxGROW | wxALL, 5);
-
-    wxButton *btn = new wxButton(this, ComboPage_Reset, "&Reset");
-    sizerLeftTop->Add(btn, 0, wxALIGN_CENTRE_HORIZONTAL | wxALL, 15);
-
-    // lower left pane
-    wxSizer *sizerLeftBottom = new wxStaticBoxSizer(wxVERTICAL, this, "&Popup");
-    sizerLeftBottom->Add(new wxButton(this, ComboPage_Popup, "&Show"),
-                         wxSizerFlags().Border().Centre());
-    sizerLeftBottom->Add(new wxButton(this, ComboPage_Dismiss, "&Hide"),
-                         wxSizerFlags().Border().Centre());
+    wxButton *btn = new wxButton(sizerLeftBottomBox, ComboPage_Reset, "&Reset");
+    sizerLeftBottom->Add(btn, 0, wxALIGN_CENTRE_HORIZONTAL | wxALL, 15);
 
 
     wxSizer *sizerLeft = new wxBoxSizer(wxVERTICAL);
@@ -299,23 +302,24 @@ void ComboboxWidgetsPage::CreateContent()
     sizerLeft->Add(sizerLeftBottom, wxSizerFlags().Expand());
 
     // middle pane
-    wxStaticBox *box2 = new wxStaticBox(this, wxID_ANY,
-        "&Change combobox contents");
-    wxSizer *sizerMiddle = new wxStaticBoxSizer(box2, wxVERTICAL);
+    wxStaticBoxSizer *sizerMiddle = new wxStaticBoxSizer(wxVERTICAL, this, "&Change combobox contents");
+    wxStaticBox* const sizerMiddleBox = sizerMiddle->GetStaticBox();
 
     wxSizer *sizerRow;
 
     sizerRow = CreateSizerWithTextAndButton(ComboPage_SetCurrent,
                                             "Current &selection",
                                             ComboPage_CurText,
-                                            &m_textCur);
+                                            &m_textCur,
+                                            sizerMiddleBox);
 
     sizerMiddle->Add(sizerRow, 0, wxALL | wxGROW, 5);
 
     wxTextCtrl *text;
     sizerRow = CreateSizerWithTextAndLabel("Insertion Point",
                                            ComboPage_InsertionPointText,
-                                           &text);
+                                           &text,
+                                           sizerMiddleBox);
     text->SetEditable(false);
 
     sizerMiddle->Add(sizerRow, 0, wxALL | wxGROW, 5);
@@ -323,52 +327,58 @@ void ComboboxWidgetsPage::CreateContent()
     sizerRow = CreateSizerWithTextAndButton(ComboPage_Insert,
                                             "&Insert this string",
                                             ComboPage_InsertText,
-                                            &m_textInsert);
+                                            &m_textInsert,
+                                            sizerMiddleBox);
     sizerMiddle->Add(sizerRow, 0, wxALL | wxGROW, 5);
 
     sizerRow = CreateSizerWithTextAndButton(ComboPage_Add,
                                             "&Add this string",
                                             ComboPage_AddText,
-                                            &m_textAdd);
+                                            &m_textAdd,
+                                            sizerMiddleBox);
     sizerMiddle->Add(sizerRow, 0, wxALL | wxGROW, 5);
 
     sizerRow = CreateSizerWithTextAndButton(ComboPage_SetFirst,
                                             "Change &1st string",
                                             ComboPage_SetFirstText,
-                                            &m_textSetFirst);
+                                            &m_textSetFirst,
+                                            sizerMiddleBox);
     sizerMiddle->Add(sizerRow, 0, wxALL | wxGROW, 5);
 
-    btn = new wxButton(this, ComboPage_AddSeveral, "&Append a few strings");
+    btn = new wxButton(sizerMiddleBox, ComboPage_AddSeveral, "&Append a few strings");
     sizerMiddle->Add(btn, 0, wxALL | wxGROW, 5);
 
-    btn = new wxButton(this, ComboPage_AddMany, "Append &many strings");
+    btn = new wxButton(sizerMiddleBox, ComboPage_AddMany, "Append &many strings");
     sizerMiddle->Add(btn, 0, wxALL | wxGROW, 5);
 
     sizerRow = CreateSizerWithTextAndButton(ComboPage_Change,
                                             "C&hange current",
                                             ComboPage_ChangeText,
-                                            &m_textChange);
+                                            &m_textChange,
+                                            sizerMiddleBox);
     sizerMiddle->Add(sizerRow, 0, wxALL | wxGROW, 5);
 
     sizerRow = CreateSizerWithTextAndButton(ComboPage_Delete,
                                             "&Delete this item",
                                             ComboPage_DeleteText,
-                                            &m_textDelete);
+                                            &m_textDelete,
+                                            sizerMiddleBox);
     sizerMiddle->Add(sizerRow, 0, wxALL | wxGROW, 5);
 
-    btn = new wxButton(this, ComboPage_DeleteSel, "Delete &selection");
+    btn = new wxButton(sizerMiddleBox, ComboPage_DeleteSel, "Delete &selection");
     sizerMiddle->Add(btn, 0, wxALL | wxGROW, 5);
 
-    btn = new wxButton(this, ComboPage_Clear, "&Clear");
+    btn = new wxButton(sizerMiddleBox, ComboPage_Clear, "&Clear");
     sizerMiddle->Add(btn, 0, wxALL | wxGROW, 5);
 
     sizerRow = CreateSizerWithTextAndButton(ComboPage_SetValue,
                                             "SetValue",
                                             ComboPage_SetValueText,
-                                            &m_textSetValue);
+                                            &m_textSetValue,
+                                            sizerMiddleBox);
     sizerMiddle->Add(sizerRow, 0, wxALL | wxGROW, 5);
 
-    btn = new wxButton(this, ComboPage_ContainerTests, "Run &tests");
+    btn = new wxButton(sizerMiddleBox, ComboPage_ContainerTests, "Run &tests");
     sizerMiddle->Add(btn, 0, wxALL | wxGROW, 5);
 
 
@@ -377,7 +387,7 @@ void ComboboxWidgetsPage::CreateContent()
     wxSizer *sizerRight = new wxBoxSizer(wxVERTICAL);
     m_combobox = new wxComboBox(this, ComboPage_Combo, wxEmptyString,
                                 wxDefaultPosition, wxDefaultSize,
-                                0, NULL,
+                                0, nullptr,
                                 0);
     sizerRight->Add(m_combobox, 0, wxGROW | wxALL, 5);
     m_combobox1 = new wxComboBox( this, ComboPage_Dynamic );
@@ -466,6 +476,8 @@ void ComboboxWidgetsPage::CreateCombo()
     delete m_combobox;
     m_combobox = newCb;
     m_combobox->SetId(ComboPage_Combo);
+
+    NotifyWidgetRecreation(m_combobox);
 }
 
 // ----------------------------------------------------------------------------
