@@ -2426,6 +2426,7 @@ void wxAuiToolBar::OnIdle(wxIdleEvent& evt)
                 if (pane.IsDocked())
                 {
                     pane.floating_size = wxDefaultSize;
+                    pane.floating_client_size = wxDefaultSize;
                 }
                 else
                 {
@@ -2467,7 +2468,7 @@ void wxAuiToolBar::UpdateBackgroundBitmap(const wxSize& size)
 {
     // We can't create 0-sized bitmaps, but we can be called with 0 size: just
     // ignore it, as we'll be called again when the window is resized.
-    if ( !size.IsAtLeast(wxSize(1, 1)) )
+    if ( size.IsEmpty() )
         return;
 
     m_backgroundBitmap.Create(size);
