@@ -2,7 +2,6 @@
 // Name:        src/common/artprov.cpp
 // Purpose:     wxArtProvider class
 // Author:      Vaclav Slavik
-// Modified by:
 // Created:     18/03/2002
 // Copyright:   (c) Vaclav Slavik
 // Licence:     wxWindows licence
@@ -19,31 +18,32 @@
 #include "wx/artprov.h"
 
 #ifndef WX_PRECOMP
-    #include "wx/list.h"
     #include "wx/log.h"
-    #include "wx/hashmap.h"
     #include "wx/image.h"
     #include "wx/module.h"
     #include "wx/window.h"
 #endif
 
-// ===========================================================================
-// implementation
-// ===========================================================================
+#include <list>
+#include <memory>
+#include <unordered_map>
 
-#include "wx/listimpl.cpp"
-WX_DECLARE_LIST(wxArtProvider, wxArtProvidersList);
-WX_DEFINE_LIST(wxArtProvidersList)
+using wxArtProviderPtr = std::unique_ptr<wxArtProvider>;
+class wxArtProvidersList : public std::list<wxArtProviderPtr>
+{
+public:
+    using std::list<wxArtProviderPtr>::list;
+};
 
 // ----------------------------------------------------------------------------
 // Cache class - stores already requested bitmaps
 // ----------------------------------------------------------------------------
 
-WX_DECLARE_EXPORTED_STRING_HASH_MAP(wxBitmap, wxArtProviderBitmapsHash);
-WX_DECLARE_EXPORTED_STRING_HASH_MAP(wxBitmapBundle, wxArtProviderBitmapBundlesHash);
-WX_DECLARE_EXPORTED_STRING_HASH_MAP(wxIconBundle, wxArtProviderIconBundlesHash);
+using wxArtProviderBitmapsHash = std::unordered_map<wxString, wxBitmap>;
+using wxArtProviderBitmapBundlesHash = std::unordered_map<wxString, wxBitmapBundle>;
+using wxArtProviderIconBundlesHash = std::unordered_map<wxString, wxIconBundle>;
 
-class WXDLLEXPORT wxArtProviderCache
+class wxArtProviderCache
 {
 public:
     bool GetBitmap(const wxString& full_id, wxBitmap* bmp);
@@ -165,24 +165,24 @@ public:
     {
     }
 
-    virtual wxSize GetDefaultSize() const wxOVERRIDE
+    virtual wxSize GetDefaultSize() const override
     {
         return m_sizeDefault;
     }
 
-    virtual wxSize GetPreferredBitmapSizeAtScale(double scale) const wxOVERRIDE
+    virtual wxSize GetPreferredBitmapSizeAtScale(double scale) const override
     {
         // Use the standard logic for integer-factor upscaling.
         return DoGetPreferredSize(scale);
     }
 
-    virtual wxBitmap GetBitmap(const wxSize& size) wxOVERRIDE
+    virtual wxBitmap GetBitmap(const wxSize& size) override
     {
         return wxArtProvider::GetBitmap(m_artId, m_artClient, size);
     }
 
 protected:
-    virtual double GetNextAvailableScale(size_t& i) const wxOVERRIDE
+    virtual double GetNextAvailableScale(size_t& i) const override
     {
         // Unfortunately we don't know what bitmap sizes are available here as
         // there is simply nothing in wxArtProvider API that returns this (and
@@ -234,8 +234,8 @@ private:
 
 wxIMPLEMENT_ABSTRACT_CLASS(wxArtProvider, wxObject);
 
-wxArtProvidersList *wxArtProvider::sm_providers = NULL;
-wxArtProviderCache *wxArtProvider::sm_cache = NULL;
+wxArtProvidersList *wxArtProvider::sm_providers = nullptr;
+wxArtProviderCache *wxArtProvider::sm_cache = nullptr;
 
 // ----------------------------------------------------------------------------
 // wxArtProvider ctors/dtor
@@ -243,7 +243,8 @@ wxArtProviderCache *wxArtProvider::sm_cache = NULL;
 
 wxArtProvider::~wxArtProvider()
 {
-    Remove(this);
+    if ( sm_providers )
+        Remove(this);
 }
 
 // ----------------------------------------------------------------------------
@@ -264,13 +265,13 @@ wxArtProvider::~wxArtProvider()
 /*static*/ void wxArtProvider::Push(wxArtProvider *provider)
 {
     CommonAddingProvider();
-    sm_providers->Insert(provider);
+    sm_providers->push_front(wxArtProviderPtr(provider));
 }
 
 /*static*/ void wxArtProvider::PushBack(wxArtProvider *provider)
 {
     CommonAddingProvider();
-    sm_providers->Append(provider);
+    sm_providers->push_back(wxArtProviderPtr(provider));
 }
 
 /*static*/ bool wxArtProvider::Pop()
@@ -278,7 +279,7 @@ wxArtProvider::~wxArtProvider()
     wxCHECK_MSG( sm_providers, false, wxT("no wxArtProvider exists") );
     wxCHECK_MSG( !sm_providers->empty(), false, wxT("wxArtProviders stack is empty") );
 
-    delete sm_providers->GetFirst()->GetData();
+    sm_providers->pop_front();
     sm_cache->Clear();
     return true;
 }
@@ -287,10 +288,19 @@ wxArtProvider::~wxArtProvider()
 {
     wxCHECK_MSG( sm_providers, false, wxT("no wxArtProvider exists") );
 
-    if ( sm_providers->DeleteObject(provider) )
+    for ( auto it = sm_providers->begin(); it != sm_providers->end(); ++it )
     {
-        sm_cache->Clear();
-        return true;
+        if ( it->get() == provider )
+        {
+            // We must not delete the provider here, the caller is responsible
+            // for doing it.
+            it->release();
+
+            sm_providers->erase(it);
+
+            sm_cache->Clear();
+            return true;
+        }
     }
 
     return false;
@@ -308,8 +318,15 @@ wxArtProvider::~wxArtProvider()
 {
     if ( sm_providers )
     {
-        while ( !sm_providers->empty() )
-            delete *sm_providers->begin();
+        // Just deleting sm_providers wouldn't work correctly because this
+        // would delete wxArtProvider objects in it which would try to remove
+        // themselves from the list in their dtor, so do it two steps instead:
+        // first clear sm_providers without deleting the objects to ensure that
+        // they don't change it while they're being destroyed, and then
+        // actually destroy them.
+        wxArtProvidersList providers;
+        providers.swap(*sm_providers);
+        providers.clear();
 
         wxDELETE(sm_providers);
         wxDELETE(sm_cache);
@@ -416,10 +433,8 @@ wxArtProvider::RescaleOrResizeIfNeeded(wxBitmap& bmp, const wxSize& sizeNeeded)
     wxBitmap bmp;
     if ( !sm_cache->GetBitmap(hashId, &bmp) )
     {
-        for (wxArtProvidersList::compatibility_iterator node = sm_providers->GetFirst();
-             node; node = node->GetNext())
+        for (const auto& provider : *sm_providers)
         {
-            wxArtProvider* const provider = node->GetData();
             bmp = provider->CreateBitmap(id, client, size);
             if ( bmp.IsOk() )
                 break;
@@ -481,10 +496,8 @@ wxBitmapBundle wxArtProvider::GetBitmapBundle(const wxArtID& id,
 
     if ( !sm_cache->GetBitmapBundle(hashId, &bitmapbundle) )
     {
-        for (wxArtProvidersList::compatibility_iterator node = sm_providers->GetFirst();
-             node; node = node->GetNext())
+        for (const auto& provider : *sm_providers)
         {
-            wxArtProvider* const provider = node->GetData();
             bitmapbundle = provider->CreateBitmapBundle(id, client, size);
             if ( bitmapbundle.IsOk() )
                 break;
@@ -546,10 +559,9 @@ wxIconBundle wxArtProvider::DoGetIconBundle(const wxArtID& id, const wxArtClient
     wxIconBundle iconbundle;
     if ( !sm_cache->GetIconBundle(hashId, &iconbundle) )
     {
-        for (wxArtProvidersList::compatibility_iterator node = sm_providers->GetFirst();
-             node; node = node->GetNext())
+        for (const auto& provider : *sm_providers)
         {
-            iconbundle = node->GetData()->CreateIconBundle(id, client);
+            iconbundle = provider->CreateIconBundle(id, client);
             if ( iconbundle.IsOk() )
                 break;
         }
@@ -607,9 +619,8 @@ wxArtID wxArtProvider::GetMessageBoxIconId(int flags)
 
 /*static*/ wxSize wxArtProvider::GetDIPSizeHint(const wxArtClient& client)
 {
-    wxArtProvidersList::compatibility_iterator node = sm_providers->GetFirst();
-    if (node)
-        return node->GetData()->DoGetSizeHint(client);
+    if ( !sm_providers->empty() )
+        return sm_providers->front()->DoGetSizeHint(client);
 
     return GetNativeDIPSizeHint(client);
 }
@@ -650,24 +661,13 @@ void wxArtProvider::InitNativeProvider()
 /* static */
 bool wxArtProvider::HasNativeProvider()
 {
-#ifdef __WXGTK20__
+#ifdef __WXGTK__
     return true;
 #else
     return false;
 #endif
 }
 
-// ----------------------------------------------------------------------------
-// deprecated wxArtProvider methods
-// ----------------------------------------------------------------------------
-
-#if WXWIN_COMPATIBILITY_2_8
-/* static */ void wxArtProvider::Insert(wxArtProvider *provider)
-{
-    PushBack(provider);
-}
-#endif // WXWIN_COMPATIBILITY_2_8
-
 // ============================================================================
 // wxArtProviderModule
 // ============================================================================
@@ -675,7 +675,7 @@ bool wxArtProvider::HasNativeProvider()
 class wxArtProviderModule: public wxModule
 {
 public:
-    bool OnInit() wxOVERRIDE
+    bool OnInit() override
     {
         // The order here is such that the native provider will be used first
         // and the standard one last as all these default providers add
@@ -689,7 +689,7 @@ public:
 #endif // wxUSE_ARTPROVIDER_STD
         return true;
     }
-    void OnExit() wxOVERRIDE
+    void OnExit() override
     {
         wxArtProvider::CleanUpProviders();
     }
