@@ -1334,7 +1334,8 @@ wxVersionInfo wxRegEx::GetLibraryVersionInfo()
     wxRegChar buf[64];
     pcre2_config(PCRE2_CONFIG_VERSION, buf);
 
-    return wxVersionInfo("PCRE2", PCRE2_MAJOR, PCRE2_MINOR, 0, buf);
+    return wxVersionInfo("PCRE2", PCRE2_MAJOR, PCRE2_MINOR, 0,
+                         wxString{ "PCRE2 " } + buf);
 }
 
 #endif // wxUSE_REGEX
