@@ -225,7 +225,7 @@ void wxPropertyGridPageState::InitNonCatMode()
 
     m_abcArray = new wxPGRootProperty(wxS("<Root_NonCat>"));
     m_abcArray->SetParentState(this);
-    m_abcArray->SetFlag(wxPGPropertyFlags::ChildrenAreCopies);
+    m_abcArray->SetFlag(wxPGFlags::ChildrenAreCopies);
 
     // Must be called when state::m_properties still points to regularArray.
     wxPGProperty* oldProperties = m_properties;
@@ -395,8 +395,8 @@ wxPGProperty* wxPropertyGridPageState::GetLastItem( int flags )
     if ( !m_properties->HasAnyChild() )
         return nullptr;
 
-    wxPGPropertyFlags itemExMask;
-    wxPGPropertyFlags parentExMask;
+    wxPGFlags itemExMask;
+    wxPGFlags parentExMask;
     wxPGCreateIteratorMasks(flags, itemExMask, parentExMask);
 
     // First, get last child of last parent if children of 'pwc' should be iterated through
@@ -603,7 +603,7 @@ void wxPropertyGridPageState::DoSortChildren(wxPGProperty* p, wxPGPropertyValues
         return;
 
     // Never sort children of aggregate properties
-    if ( p->HasFlag(wxPGPropertyFlags::Aggregate) )
+    if ( p->HasFlag(wxPGFlags::Aggregate) )
         return;
 
     if ( !!(flags & wxPGPropertyValuesFlags::SortTopLevelOnly)
@@ -1383,12 +1383,12 @@ wxVariant wxPropertyGridPageState::DoGetPropertyValues(const wxString& listname,
     {
         if ( !!(flags & wxPGPropertyValuesFlags::KeepStructure) )
         {
-            wxASSERT( !pwc->HasFlag(wxPGPropertyFlags::Aggregate) );
+            wxASSERT( !pwc->HasFlag(wxPGFlags::Aggregate) );
 
             for ( unsigned int i = 0; i < pwc->GetChildCount(); i++ )
             {
                 wxPGProperty* p = pwc->Item(i);
-                if ( !p->HasAnyChild() || p->HasFlag(wxPGPropertyFlags::Aggregate) )
+                if ( !p->HasAnyChild() || p->HasFlag(wxPGFlags::Aggregate) )
                 {
                     wxVariant variant = p->GetValue();
                     variant.SetName( p->GetBaseName() );
@@ -1412,7 +1412,7 @@ wxVariant wxPropertyGridPageState::DoGetPropertyValues(const wxString& listname,
                 const wxPGProperty* p = it.GetProperty();
 
                 // Use a trick to ignore wxParentProperty itself, but not its sub-properties.
-                if ( !p->HasAnyChild() || p->HasFlag(wxPGPropertyFlags::Aggregate) )
+                if ( !p->HasAnyChild() || p->HasFlag(wxPGFlags::Aggregate) )
                 {
                     wxVariant variant = p->GetValue();
                     variant.SetName( p->GetName() );
@@ -1672,7 +1672,7 @@ wxPGProperty* wxPropertyGridPageState::DoInsert( wxPGProperty* parent, int index
     if ( !parent )
         parent = m_properties;
 
-    wxCHECK_MSG( !parent->HasFlag(wxPGPropertyFlags::Aggregate),
+    wxCHECK_MSG( !parent->HasFlag(wxPGFlags::Aggregate),
                  wxNullProperty,
                  wxS("when adding properties to fixed parents, use BeginAddChildren and EndAddChildren.") );
 
@@ -1742,7 +1742,7 @@ wxPGProperty* wxPropertyGridPageState::DoInsert( wxPGProperty* parent, int index
 
     // Update editor controls of all parents if they are containers of composed values.
     for( wxPGProperty *p = property->GetParent();
-         p && !p->IsRoot() && !p->IsCategory() && p->HasFlag(wxPGPropertyFlags::ComposedValue);
+         p && !p->IsRoot() && !p->IsCategory() && p->HasFlag(wxPGFlags::ComposedValue);
          p = p->GetParent() )
     {
         p->RefreshEditor();
@@ -1790,7 +1790,7 @@ void wxPropertyGridPageState::DoMarkChildrenAsDeleted(wxPGProperty* p,
     {
         wxPGProperty* child = p->Item(i);
 
-        child->SetFlag(wxPGPropertyFlags::BeingDeleted);
+        child->SetFlag(wxPGFlags::BeingDeleted);
 
         if ( recursive )
         {
@@ -1893,7 +1893,7 @@ void wxPropertyGridPageState::DoDelete( wxPGProperty* item, bool doDelete )
 
     wxPGProperty* parent = item->GetParent();
 
-    wxCHECK_RET( !parent->HasFlag(wxPGPropertyFlags::Aggregate),
+    wxCHECK_RET( !parent->HasFlag(wxPGFlags::Aggregate),
         wxS("wxPropertyGrid: Do not attempt to remove sub-properties.") );
 
     wxASSERT( item->GetParentState() == this );
@@ -1960,13 +1960,13 @@ void wxPropertyGridPageState::DoDelete( wxPGProperty* item, bool doDelete )
                   wxS("Current category cannot be deleted") );
 
     // Prevent property and its children from being re-selected
-    item->SetFlag(wxPGPropertyFlags::BeingDeleted);
+    item->SetFlag(wxPGFlags::BeingDeleted);
     DoMarkChildrenAsDeleted(item, true);
 
     unsigned int indinparent = item->GetIndexInParent();
 
     // Delete children
-    if ( item->HasAnyChild() && !item->HasFlag(wxPGPropertyFlags::Aggregate) )
+    if ( item->HasAnyChild() && !item->HasFlag(wxPGFlags::Aggregate) )
     {
         // deleting a category
         item->DeleteChildren();
